@@ -66,8 +66,8 @@ import com.openexchange.database.DatabaseService;
 import com.openexchange.database.Databases;
 import com.openexchange.exception.OXException;
 import com.openexchange.oauth.provider.exceptions.OAuthProviderExceptionCodes;
-import com.openexchange.oauth.provider.scope.Scope;
-import com.openexchange.oauth.provider.tools.UserizedToken;
+import com.openexchange.oauth.provider.impl.tools.UserizedToken;
+import com.openexchange.oauth.provider.resourceserver.scope.Scope;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.update.Tools;
 
